==> jc-1.4.0.tar.gz: polyglot/frontend/GlobalBarrierPass.h <==
// public class polyglot.frontend.GlobalBarrierPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class e0a64384fd8897ef polyglot_frontend_BarrierPass
// @dep_class 59b8358f61d4a29c polyglot_frontend_GlobalBarrierPass

// header file dependencies
// @dep_header polyglot_frontend_BarrierPass

#include "polyglot/frontend/BarrierPass.h"

#ifndef _JC_polyglot_frontend_GlobalBarrierPass_H_
#define _JC_polyglot_frontend_GlobalBarrierPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$sub_refs	_jc_polyglot_frontend_GlobalBarrierPass$sub_refs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs	_jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$refs	_jc_polyglot_frontend_GlobalBarrierPass$refs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$nonrefs	_jc_polyglot_frontend_GlobalBarrierPass$nonrefs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$object	_jc_polyglot_frontend_GlobalBarrierPass$object;

typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vmethods	_jc_polyglot_frontend_GlobalBarrierPass$vmethods;
typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vtable	_jc_polyglot_frontend_GlobalBarrierPass$vtable;
typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vtype	_jc_polyglot_frontend_GlobalBarrierPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_GlobalBarrierPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_GlobalBarrierPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *);

// Virtual methods structure
struct _jc_polyglot_frontend_GlobalBarrierPass$vmethods {
};

// Vtable
struct _jc_polyglot_frontend_GlobalBarrierPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_BarrierPass$vmethods	polyglot_frontend_BarrierPass;
	_jc_polyglot_frontend_GlobalBarrierPass$vmethods	polyglot_frontend_GlobalBarrierPass;
};

// Vtype
struct _jc_polyglot_frontend_GlobalBarrierPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_GlobalBarrierPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_GlobalBarrierPass$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_GlobalBarrierPass$refs {
    _jc_polyglot_frontend_GlobalBarrierPass$sub_refs	polyglot_frontend_GlobalBarrierPass;
    _jc_polyglot_frontend_BarrierPass$sub_refs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_GlobalBarrierPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_BarrierPass$sub_nonrefs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs	polyglot_frontend_GlobalBarrierPass;
};

// Object instance structure
struct _jc_polyglot_frontend_GlobalBarrierPass$object {
	_jc_polyglot_frontend_GlobalBarrierPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_GlobalBarrierPass$vtype	*vtype;
	_jc_polyglot_frontend_GlobalBarrierPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_GlobalBarrierPass$vtype _jc_polyglot_frontend_GlobalBarrierPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_GlobalBarrierPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_GlobalBarrierPass$class_object;

#endif	/* _JC_polyglot_frontend_GlobalBarrierPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/GlobalBarrierPass.h <==
// public class polyglot.frontend.GlobalBarrierPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class e0a64384fd8897ef polyglot_frontend_BarrierPass
// @dep_class 59b8358f61d4a29c polyglot_frontend_GlobalBarrierPass

// header file dependencies
// @dep_header polyglot_frontend_BarrierPass

#include "polyglot/frontend/BarrierPass.h"

#ifndef _JC_polyglot_frontend_GlobalBarrierPass_H_
#define _JC_polyglot_frontend_GlobalBarrierPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$sub_refs	_jc_polyglot_frontend_GlobalBarrierPass$sub_refs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs	_jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$refs	_jc_polyglot_frontend_GlobalBarrierPass$refs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$nonrefs	_jc_polyglot_frontend_GlobalBarrierPass$nonrefs;
typedef struct _jc_polyglot_frontend_GlobalBarrierPass$object	_jc_polyglot_frontend_GlobalBarrierPass$object;

typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vmethods	_jc_polyglot_frontend_GlobalBarrierPass$vmethods;
typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vtable	_jc_polyglot_frontend_GlobalBarrierPass$vtable;
typedef const struct _jc_polyglot_frontend_GlobalBarrierPass$vtype	_jc_polyglot_frontend_GlobalBarrierPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_GlobalBarrierPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_GlobalBarrierPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_frontend_GlobalBarrierPass$vmethods {
};

// Vtable
struct _jc_polyglot_frontend_GlobalBarrierPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_BarrierPass$vmethods	polyglot_frontend_BarrierPass;
	_jc_polyglot_frontend_GlobalBarrierPass$vmethods	polyglot_frontend_GlobalBarrierPass;
};

// Vtype
struct _jc_polyglot_frontend_GlobalBarrierPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_GlobalBarrierPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_GlobalBarrierPass$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_GlobalBarrierPass$refs {
    _jc_polyglot_frontend_GlobalBarrierPass$sub_refs	polyglot_frontend_GlobalBarrierPass;
    _jc_polyglot_frontend_BarrierPass$sub_refs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_GlobalBarrierPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_BarrierPass$sub_nonrefs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_GlobalBarrierPass$sub_nonrefs	polyglot_frontend_GlobalBarrierPass;
};

// Object instance structure
struct _jc_polyglot_frontend_GlobalBarrierPass$object {
	_jc_polyglot_frontend_GlobalBarrierPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_GlobalBarrierPass$vtype	*vtype;
	_jc_polyglot_frontend_GlobalBarrierPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_GlobalBarrierPass$vtype _jc_polyglot_frontend_GlobalBarrierPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_GlobalBarrierPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_GlobalBarrierPass$class_object;

#endif	/* _JC_polyglot_frontend_GlobalBarrierPass_H_ */
